Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterConnectionServiceServer(s grpc.ServiceRegistrar, srv ConnectionServiceServer)
- type CloudSqlCredential
- func (*CloudSqlCredential) Descriptor() ([]byte, []int)deprecated
- func (x *CloudSqlCredential) GetPassword() string
- func (x *CloudSqlCredential) GetUsername() string
- func (*CloudSqlCredential) ProtoMessage()
- func (x *CloudSqlCredential) ProtoReflect() protoreflect.Message
- func (x *CloudSqlCredential) Reset()
- func (x *CloudSqlCredential) String() string
- type CloudSqlProperties
- func (*CloudSqlProperties) Descriptor() ([]byte, []int)deprecated
- func (x *CloudSqlProperties) GetCredential() *CloudSqlCredential
- func (x *CloudSqlProperties) GetDatabase() string
- func (x *CloudSqlProperties) GetInstanceId() string
- func (x *CloudSqlProperties) GetServiceAccountId() string
- func (x *CloudSqlProperties) GetType() CloudSqlProperties_DatabaseType
- func (*CloudSqlProperties) ProtoMessage()
- func (x *CloudSqlProperties) ProtoReflect() protoreflect.Message
- func (x *CloudSqlProperties) Reset()
- func (x *CloudSqlProperties) String() string
- type CloudSqlProperties_DatabaseType
- func (CloudSqlProperties_DatabaseType) Descriptor() protoreflect.EnumDescriptor
- func (x CloudSqlProperties_DatabaseType) Enum() *CloudSqlProperties_DatabaseType
- func (CloudSqlProperties_DatabaseType) EnumDescriptor() ([]byte, []int)deprecated
- func (x CloudSqlProperties_DatabaseType) Number() protoreflect.EnumNumber
- func (x CloudSqlProperties_DatabaseType) String() string
- func (CloudSqlProperties_DatabaseType) Type() protoreflect.EnumType
- type Connection
- func (*Connection) Descriptor() ([]byte, []int)deprecated
- func (x *Connection) GetCloudSql() *CloudSqlProperties
- func (x *Connection) GetCreationTime() int64
- func (x *Connection) GetDescription() string
- func (x *Connection) GetFriendlyName() string
- func (x *Connection) GetHasCredential() bool
- func (x *Connection) GetLastModifiedTime() int64
- func (x *Connection) GetName() string
- func (m *Connection) GetProperties() isConnection_Properties
- func (*Connection) ProtoMessage()
- func (x *Connection) ProtoReflect() protoreflect.Message
- func (x *Connection) Reset()
- func (x *Connection) String() string
- type ConnectionCredential
- func (*ConnectionCredential) Descriptor() ([]byte, []int)deprecated
- func (x *ConnectionCredential) GetCloudSql() *CloudSqlCredential
- func (m *ConnectionCredential) GetCredential() isConnectionCredential_Credential
- func (*ConnectionCredential) ProtoMessage()
- func (x *ConnectionCredential) ProtoReflect() protoreflect.Message
- func (x *ConnectionCredential) Reset()
- func (x *ConnectionCredential) String() string
- type ConnectionCredential_CloudSql
- type ConnectionServiceClient
- type ConnectionServiceServer
- type Connection_CloudSql
- type CreateConnectionRequest
- func (*CreateConnectionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateConnectionRequest) GetConnection() *Connection
- func (x *CreateConnectionRequest) GetConnectionId() string
- func (x *CreateConnectionRequest) GetParent() string
- func (*CreateConnectionRequest) ProtoMessage()
- func (x *CreateConnectionRequest) ProtoReflect() protoreflect.Message
- func (x *CreateConnectionRequest) Reset()
- func (x *CreateConnectionRequest) String() string
- type DeleteConnectionRequest
- func (*DeleteConnectionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteConnectionRequest) GetName() string
- func (*DeleteConnectionRequest) ProtoMessage()
- func (x *DeleteConnectionRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteConnectionRequest) Reset()
- func (x *DeleteConnectionRequest) String() string
- type GetConnectionRequest
- func (*GetConnectionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetConnectionRequest) GetName() string
- func (*GetConnectionRequest) ProtoMessage()
- func (x *GetConnectionRequest) ProtoReflect() protoreflect.Message
- func (x *GetConnectionRequest) Reset()
- func (x *GetConnectionRequest) String() string
- type ListConnectionsRequest
- func (*ListConnectionsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ListConnectionsRequest) GetMaxResults() *wrapperspb.UInt32Value
- func (x *ListConnectionsRequest) GetPageToken() string
- func (x *ListConnectionsRequest) GetParent() string
- func (*ListConnectionsRequest) ProtoMessage()
- func (x *ListConnectionsRequest) ProtoReflect() protoreflect.Message
- func (x *ListConnectionsRequest) Reset()
- func (x *ListConnectionsRequest) String() string
- type ListConnectionsResponse
- func (*ListConnectionsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListConnectionsResponse) GetConnections() []*Connection
- func (x *ListConnectionsResponse) GetNextPageToken() string
- func (*ListConnectionsResponse) ProtoMessage()
- func (x *ListConnectionsResponse) ProtoReflect() protoreflect.Message
- func (x *ListConnectionsResponse) Reset()
- func (x *ListConnectionsResponse) String() string
- type UnimplementedConnectionServiceServer
- func (UnimplementedConnectionServiceServer) CreateConnection(context.Context, *CreateConnectionRequest) (*Connection, error)
- func (UnimplementedConnectionServiceServer) DeleteConnection(context.Context, *DeleteConnectionRequest) (*emptypb.Empty, error)
- func (UnimplementedConnectionServiceServer) GetConnection(context.Context, *GetConnectionRequest) (*Connection, error)
- func (UnimplementedConnectionServiceServer) GetIamPolicy(context.Context, *iampb.GetIamPolicyRequest) (*iampb.Policy, error)
- func (UnimplementedConnectionServiceServer) ListConnections(context.Context, *ListConnectionsRequest) (*ListConnectionsResponse, error)
- func (UnimplementedConnectionServiceServer) SetIamPolicy(context.Context, *iampb.SetIamPolicyRequest) (*iampb.Policy, error)
- func (UnimplementedConnectionServiceServer) TestIamPermissions(context.Context, *iampb.TestIamPermissionsRequest) (*iampb.TestIamPermissionsResponse, error)
- func (UnimplementedConnectionServiceServer) UpdateConnection(context.Context, *UpdateConnectionRequest) (*Connection, error)
- func (UnimplementedConnectionServiceServer) UpdateConnectionCredential(context.Context, *UpdateConnectionCredentialRequest) (*emptypb.Empty, error)
- type UnsafeConnectionServiceServer
- type UpdateConnectionCredentialRequest
- func (*UpdateConnectionCredentialRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateConnectionCredentialRequest) GetCredential() *ConnectionCredential
- func (x *UpdateConnectionCredentialRequest) GetName() string
- func (*UpdateConnectionCredentialRequest) ProtoMessage()
- func (x *UpdateConnectionCredentialRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateConnectionCredentialRequest) Reset()
- func (x *UpdateConnectionCredentialRequest) String() string
- type UpdateConnectionRequest
- func (*UpdateConnectionRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateConnectionRequest) GetConnection() *Connection
- func (x *UpdateConnectionRequest) GetName() string
- func (x *UpdateConnectionRequest) GetUpdateMask() *fieldmaskpb.FieldMask
- func (*UpdateConnectionRequest) ProtoMessage()
- func (x *UpdateConnectionRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateConnectionRequest) Reset()
- func (x *UpdateConnectionRequest) String() string
Constants ¶
const ( ConnectionService_CreateConnection_FullMethodName = "/google.cloud.bigquery.connection.v1beta1.ConnectionService/CreateConnection" ConnectionService_GetConnection_FullMethodName = "/google.cloud.bigquery.connection.v1beta1.ConnectionService/GetConnection" ConnectionService_ListConnections_FullMethodName = "/google.cloud.bigquery.connection.v1beta1.ConnectionService/ListConnections" ConnectionService_UpdateConnection_FullMethodName = "/google.cloud.bigquery.connection.v1beta1.ConnectionService/UpdateConnection" ConnectionService_UpdateConnectionCredential_FullMethodName = "/google.cloud.bigquery.connection.v1beta1.ConnectionService/UpdateConnectionCredential" ConnectionService_DeleteConnection_FullMethodName = "/google.cloud.bigquery.connection.v1beta1.ConnectionService/DeleteConnection" ConnectionService_GetIamPolicy_FullMethodName = "/google.cloud.bigquery.connection.v1beta1.ConnectionService/GetIamPolicy" ConnectionService_SetIamPolicy_FullMethodName = "/google.cloud.bigquery.connection.v1beta1.ConnectionService/SetIamPolicy" ConnectionService_TestIamPermissions_FullMethodName = "/google.cloud.bigquery.connection.v1beta1.ConnectionService/TestIamPermissions" )
Variables ¶
var ( CloudSqlProperties_DatabaseType_name = map[int32]string{ 0: "DATABASE_TYPE_UNSPECIFIED", 1: "POSTGRES", 2: "MYSQL", } CloudSqlProperties_DatabaseType_value = map[string]int32{ "DATABASE_TYPE_UNSPECIFIED": 0, "POSTGRES": 1, "MYSQL": 2, } )
Enum value maps for CloudSqlProperties_DatabaseType.
var ConnectionService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "google.cloud.bigquery.connection.v1beta1.ConnectionService", HandlerType: (*ConnectionServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateConnection", Handler: _ConnectionService_CreateConnection_Handler, }, { MethodName: "GetConnection", Handler: _ConnectionService_GetConnection_Handler, }, { MethodName: "ListConnections", Handler: _ConnectionService_ListConnections_Handler, }, { MethodName: "UpdateConnection", Handler: _ConnectionService_UpdateConnection_Handler, }, { MethodName: "UpdateConnectionCredential", Handler: _ConnectionService_UpdateConnectionCredential_Handler, }, { MethodName: "DeleteConnection", Handler: _ConnectionService_DeleteConnection_Handler, }, { MethodName: "GetIamPolicy", Handler: _ConnectionService_GetIamPolicy_Handler, }, { MethodName: "SetIamPolicy", Handler: _ConnectionService_SetIamPolicy_Handler, }, { MethodName: "TestIamPermissions", Handler: _ConnectionService_TestIamPermissions_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "google/cloud/bigquery/connection/v1beta1/connection.proto", }
ConnectionService_ServiceDesc is the grpc.ServiceDesc for ConnectionService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_google_cloud_bigquery_connection_v1beta1_connection_proto protoreflect.FileDescriptor
Functions ¶
func RegisterConnectionServiceServer ¶
func RegisterConnectionServiceServer(s grpc.ServiceRegistrar, srv ConnectionServiceServer)
Types ¶
type CloudSqlCredential ¶
type CloudSqlCredential struct {
// The username for the credential.
Username string `protobuf:"bytes,1,opt,name=username,proto3" json:"username,omitempty"`
// The password for the credential.
Password string `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
// contains filtered or unexported fields
}
Credential info for the Cloud SQL.
func (*CloudSqlCredential) Descriptor
deprecated
func (*CloudSqlCredential) Descriptor() ([]byte, []int)
Deprecated: Use CloudSqlCredential.ProtoReflect.Descriptor instead.
func (*CloudSqlCredential) GetPassword ¶
func (x *CloudSqlCredential) GetPassword() string
func (*CloudSqlCredential) GetUsername ¶
func (x *CloudSqlCredential) GetUsername() string
func (*CloudSqlCredential) ProtoMessage ¶
func (*CloudSqlCredential) ProtoMessage()
func (*CloudSqlCredential) ProtoReflect ¶
func (x *CloudSqlCredential) ProtoReflect() protoreflect.Message
func (*CloudSqlCredential) Reset ¶
func (x *CloudSqlCredential) Reset()
func (*CloudSqlCredential) String ¶
func (x *CloudSqlCredential) String() string
type CloudSqlProperties ¶
type CloudSqlProperties struct {
// Cloud SQL instance ID in the form `project:location:instance`.
InstanceId string `protobuf:"bytes,1,opt,name=instance_id,json=instanceId,proto3" json:"instance_id,omitempty"`
// Database name.
Database string `protobuf:"bytes,2,opt,name=database,proto3" json:"database,omitempty"`
// Type of the Cloud SQL database.
Type CloudSqlProperties_DatabaseType `` /* 140-byte string literal not displayed */
// Input only. Cloud SQL credential.
Credential *CloudSqlCredential `protobuf:"bytes,4,opt,name=credential,proto3" json:"credential,omitempty"`
// Output only. The account ID of the service used for the purpose of this
// connection.
//
// When the connection is used in the context of an operation in
// BigQuery, this service account will serve as the identity being used for
// connecting to the CloudSQL instance specified in this connection.
ServiceAccountId string `protobuf:"bytes,5,opt,name=service_account_id,json=serviceAccountId,proto3" json:"service_account_id,omitempty"`
// contains filtered or unexported fields
}
Connection properties specific to the Cloud SQL.
func (*CloudSqlProperties) Descriptor
deprecated
func (*CloudSqlProperties) Descriptor() ([]byte, []int)
Deprecated: Use CloudSqlProperties.ProtoReflect.Descriptor instead.
func (*CloudSqlProperties) GetCredential ¶
func (x *CloudSqlProperties) GetCredential() *CloudSqlCredential
func (*CloudSqlProperties) GetDatabase ¶
func (x *CloudSqlProperties) GetDatabase() string
func (*CloudSqlProperties) GetInstanceId ¶
func (x *CloudSqlProperties) GetInstanceId() string
func (*CloudSqlProperties) GetServiceAccountId ¶
func (x *CloudSqlProperties) GetServiceAccountId() string
func (*CloudSqlProperties) GetType ¶
func (x *CloudSqlProperties) GetType() CloudSqlProperties_DatabaseType
func (*CloudSqlProperties) ProtoMessage ¶
func (*CloudSqlProperties) ProtoMessage()
func (*CloudSqlProperties) ProtoReflect ¶
func (x *CloudSqlProperties) ProtoReflect() protoreflect.Message
func (*CloudSqlProperties) Reset ¶
func (x *CloudSqlProperties) Reset()
func (*CloudSqlProperties) String ¶
func (x *CloudSqlProperties) String() string
type CloudSqlProperties_DatabaseType ¶
type CloudSqlProperties_DatabaseType int32
Supported Cloud SQL database types.
const ( // Unspecified database type. CloudSqlProperties_DATABASE_TYPE_UNSPECIFIED CloudSqlProperties_DatabaseType = 0 // Cloud SQL for PostgreSQL. CloudSqlProperties_POSTGRES CloudSqlProperties_DatabaseType = 1 // Cloud SQL for MySQL. CloudSqlProperties_MYSQL CloudSqlProperties_DatabaseType = 2 )
func (CloudSqlProperties_DatabaseType) Descriptor ¶
func (CloudSqlProperties_DatabaseType) Descriptor() protoreflect.EnumDescriptor
func (CloudSqlProperties_DatabaseType) Enum ¶
func (x CloudSqlProperties_DatabaseType) Enum() *CloudSqlProperties_DatabaseType
func (CloudSqlProperties_DatabaseType) EnumDescriptor
deprecated
func (CloudSqlProperties_DatabaseType) EnumDescriptor() ([]byte, []int)
Deprecated: Use CloudSqlProperties_DatabaseType.Descriptor instead.
func (CloudSqlProperties_DatabaseType) Number ¶
func (x CloudSqlProperties_DatabaseType) Number() protoreflect.EnumNumber
func (CloudSqlProperties_DatabaseType) String ¶
func (x CloudSqlProperties_DatabaseType) String() string
func (CloudSqlProperties_DatabaseType) Type ¶
func (CloudSqlProperties_DatabaseType) Type() protoreflect.EnumType
type Connection ¶
type Connection struct {
// The resource name of the connection in the form of:
// `projects/{project_id}/locations/{location_id}/connections/{connection_id}`
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// User provided display name for the connection.
FriendlyName string `protobuf:"bytes,2,opt,name=friendly_name,json=friendlyName,proto3" json:"friendly_name,omitempty"`
// User provided description.
Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
// Properties specific to the underlying data source.
//
// Types that are assignable to Properties:
//
// *Connection_CloudSql
Properties isConnection_Properties `protobuf_oneof:"properties"`
// Output only. The creation timestamp of the connection.
CreationTime int64 `protobuf:"varint,5,opt,name=creation_time,json=creationTime,proto3" json:"creation_time,omitempty"`
// Output only. The last update timestamp of the connection.
LastModifiedTime int64 `protobuf:"varint,6,opt,name=last_modified_time,json=lastModifiedTime,proto3" json:"last_modified_time,omitempty"`
// Output only. True, if credential is configured for this connection.
HasCredential bool `protobuf:"varint,7,opt,name=has_credential,json=hasCredential,proto3" json:"has_credential,omitempty"`
// contains filtered or unexported fields
}
Configuration parameters to establish connection with an external data source, except the credential attributes.
func (*Connection) Descriptor
deprecated
func (*Connection) Descriptor() ([]byte, []int)
Deprecated: Use Connection.ProtoReflect.Descriptor instead.
func (*Connection) GetCloudSql ¶
func (x *Connection) GetCloudSql() *CloudSqlProperties
func (*Connection) GetCreationTime ¶
func (x *Connection) GetCreationTime() int64
func (*Connection) GetDescription ¶
func (x *Connection) GetDescription() string
func (*Connection) GetFriendlyName ¶
func (x *Connection) GetFriendlyName() string
func (*Connection) GetHasCredential ¶
func (x *Connection) GetHasCredential() bool
func (*Connection) GetLastModifiedTime ¶
func (x *Connection) GetLastModifiedTime() int64
func (*Connection) GetName ¶
func (x *Connection) GetName() string
func (*Connection) GetProperties ¶
func (m *Connection) GetProperties() isConnection_Properties
func (*Connection) ProtoMessage ¶
func (*Connection) ProtoMessage()
func (*Connection) ProtoReflect ¶
func (x *Connection) ProtoReflect() protoreflect.Message
func (*Connection) Reset ¶
func (x *Connection) Reset()
func (*Connection) String ¶
func (x *Connection) String() string
type ConnectionCredential ¶
type ConnectionCredential struct {
// Credential specific to the underlying data source.
//
// Types that are assignable to Credential:
//
// *ConnectionCredential_CloudSql
Credential isConnectionCredential_Credential `protobuf_oneof:"credential"`
// contains filtered or unexported fields
}
Credential to use with a connection.
func (*ConnectionCredential) Descriptor
deprecated
func (*ConnectionCredential) Descriptor() ([]byte, []int)
Deprecated: Use ConnectionCredential.ProtoReflect.Descriptor instead.
func (*ConnectionCredential) GetCloudSql ¶
func (x *ConnectionCredential) GetCloudSql() *CloudSqlCredential
func (*ConnectionCredential) GetCredential ¶
func (m *ConnectionCredential) GetCredential() isConnectionCredential_Credential
func (*ConnectionCredential) ProtoMessage ¶
func (*ConnectionCredential) ProtoMessage()
func (*ConnectionCredential) ProtoReflect ¶
func (x *ConnectionCredential) ProtoReflect() protoreflect.Message
func (*ConnectionCredential) Reset ¶
func (x *ConnectionCredential) Reset()
func (*ConnectionCredential) String ¶
func (x *ConnectionCredential) String() string
type ConnectionCredential_CloudSql ¶
type ConnectionCredential_CloudSql struct {
// Credential for Cloud SQL database.
CloudSql *CloudSqlCredential `protobuf:"bytes,1,opt,name=cloud_sql,json=cloudSql,proto3,oneof"`
}
type ConnectionServiceClient ¶
type ConnectionServiceClient interface {
// Creates a new connection.
CreateConnection(ctx context.Context, in *CreateConnectionRequest, opts ...grpc.CallOption) (*Connection, error)
// Returns specified connection.
GetConnection(ctx context.Context, in *GetConnectionRequest, opts ...grpc.CallOption) (*Connection, error)
// Returns a list of connections in the given project.
ListConnections(ctx context.Context, in *ListConnectionsRequest, opts ...grpc.CallOption) (*ListConnectionsResponse, error)
// Updates the specified connection. For security reasons, also resets
// credential if connection properties are in the update field mask.
UpdateConnection(ctx context.Context, in *UpdateConnectionRequest, opts ...grpc.CallOption) (*Connection, error)
// Sets the credential for the specified connection.
UpdateConnectionCredential(ctx context.Context, in *UpdateConnectionCredentialRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
// Deletes connection and associated credential.
DeleteConnection(ctx context.Context, in *DeleteConnectionRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
// Gets the access control policy for a resource.
// Returns an empty policy if the resource exists and does not have a policy
// set.
GetIamPolicy(ctx context.Context, in *iampb.GetIamPolicyRequest, opts ...grpc.CallOption) (*iampb.Policy, error)
// Sets the access control policy on the specified resource. Replaces any
// existing policy.
//
// Can return `NOT_FOUND`, `INVALID_ARGUMENT`, and `PERMISSION_DENIED` errors.
SetIamPolicy(ctx context.Context, in *iampb.SetIamPolicyRequest, opts ...grpc.CallOption) (*iampb.Policy, error)
// Returns permissions that a caller has on the specified resource.
// If the resource does not exist, this will return an empty set of
// permissions, not a `NOT_FOUND` error.
//
// Note: This operation is designed to be used for building permission-aware
// UIs and command-line tools, not for authorization checking. This operation
// may "fail open" without warning.
TestIamPermissions(ctx context.Context, in *iampb.TestIamPermissionsRequest, opts ...grpc.CallOption) (*iampb.TestIamPermissionsResponse, error)
}
ConnectionServiceClient is the client API for ConnectionService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewConnectionServiceClient ¶
func NewConnectionServiceClient(cc grpc.ClientConnInterface) ConnectionServiceClient
type ConnectionServiceServer ¶
type ConnectionServiceServer interface {
// Creates a new connection.
CreateConnection(context.Context, *CreateConnectionRequest) (*Connection, error)
// Returns specified connection.
GetConnection(context.Context, *GetConnectionRequest) (*Connection, error)
// Returns a list of connections in the given project.
ListConnections(context.Context, *ListConnectionsRequest) (*ListConnectionsResponse, error)
// Updates the specified connection. For security reasons, also resets
// credential if connection properties are in the update field mask.
UpdateConnection(context.Context, *UpdateConnectionRequest) (*Connection, error)
// Sets the credential for the specified connection.
UpdateConnectionCredential(context.Context, *UpdateConnectionCredentialRequest) (*emptypb.Empty, error)
// Deletes connection and associated credential.
DeleteConnection(context.Context, *DeleteConnectionRequest) (*emptypb.Empty, error)
// Gets the access control policy for a resource.
// Returns an empty policy if the resource exists and does not have a policy
// set.
GetIamPolicy(context.Context, *iampb.GetIamPolicyRequest) (*iampb.Policy, error)
// Sets the access control policy on the specified resource. Replaces any
// existing policy.
//
// Can return `NOT_FOUND`, `INVALID_ARGUMENT`, and `PERMISSION_DENIED` errors.
SetIamPolicy(context.Context, *iampb.SetIamPolicyRequest) (*iampb.Policy, error)
// Returns permissions that a caller has on the specified resource.
// If the resource does not exist, this will return an empty set of
// permissions, not a `NOT_FOUND` error.
//
// Note: This operation is designed to be used for building permission-aware
// UIs and command-line tools, not for authorization checking. This operation
// may "fail open" without warning.
TestIamPermissions(context.Context, *iampb.TestIamPermissionsRequest) (*iampb.TestIamPermissionsResponse, error)
}
ConnectionServiceServer is the server API for ConnectionService service. All implementations should embed UnimplementedConnectionServiceServer for forward compatibility
type Connection_CloudSql ¶
type Connection_CloudSql struct {
// Cloud SQL properties.
CloudSql *CloudSqlProperties `protobuf:"bytes,4,opt,name=cloud_sql,json=cloudSql,proto3,oneof"`
}
type CreateConnectionRequest ¶
type CreateConnectionRequest struct {
// Required. Parent resource name.
// Must be in the format `projects/{project_id}/locations/{location_id}`
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// Optional. Connection id that should be assigned to the created connection.
ConnectionId string `protobuf:"bytes,2,opt,name=connection_id,json=connectionId,proto3" json:"connection_id,omitempty"`
// Required. Connection to create.
Connection *Connection `protobuf:"bytes,3,opt,name=connection,proto3" json:"connection,omitempty"`
// contains filtered or unexported fields
}
The request for [ConnectionService.CreateConnection][google.cloud.bigquery.connection.v1beta1.ConnectionService.CreateConnection].
func (*CreateConnectionRequest) Descriptor
deprecated
func (*CreateConnectionRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateConnectionRequest.ProtoReflect.Descriptor instead.
func (*CreateConnectionRequest) GetConnection ¶
func (x *CreateConnectionRequest) GetConnection() *Connection
func (*CreateConnectionRequest) GetConnectionId ¶
func (x *CreateConnectionRequest) GetConnectionId() string
func (*CreateConnectionRequest) GetParent ¶
func (x *CreateConnectionRequest) GetParent() string
func (*CreateConnectionRequest) ProtoMessage ¶
func (*CreateConnectionRequest) ProtoMessage()
func (*CreateConnectionRequest) ProtoReflect ¶
func (x *CreateConnectionRequest) ProtoReflect() protoreflect.Message
func (*CreateConnectionRequest) Reset ¶
func (x *CreateConnectionRequest) Reset()
func (*CreateConnectionRequest) String ¶
func (x *CreateConnectionRequest) String() string
type DeleteConnectionRequest ¶
type DeleteConnectionRequest struct {
// Required. Name of the deleted connection, for example:
// `projects/{project_id}/locations/{location_id}/connections/{connection_id}`
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
The request for [ConnectionService.DeleteConnectionRequest][].
func (*DeleteConnectionRequest) Descriptor
deprecated
func (*DeleteConnectionRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteConnectionRequest.ProtoReflect.Descriptor instead.
func (*DeleteConnectionRequest) GetName ¶
func (x *DeleteConnectionRequest) GetName() string
func (*DeleteConnectionRequest) ProtoMessage ¶
func (*DeleteConnectionRequest) ProtoMessage()
func (*DeleteConnectionRequest) ProtoReflect ¶
func (x *DeleteConnectionRequest) ProtoReflect() protoreflect.Message
func (*DeleteConnectionRequest) Reset ¶
func (x *DeleteConnectionRequest) Reset()
func (*DeleteConnectionRequest) String ¶
func (x *DeleteConnectionRequest) String() string
type GetConnectionRequest ¶
type GetConnectionRequest struct {
// Required. Name of the requested connection, for example:
// `projects/{project_id}/locations/{location_id}/connections/{connection_id}`
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
The request for [ConnectionService.GetConnection][google.cloud.bigquery.connection.v1beta1.ConnectionService.GetConnection].
func (*GetConnectionRequest) Descriptor
deprecated
func (*GetConnectionRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetConnectionRequest.ProtoReflect.Descriptor instead.
func (*GetConnectionRequest) GetName ¶
func (x *GetConnectionRequest) GetName() string
func (*GetConnectionRequest) ProtoMessage ¶
func (*GetConnectionRequest) ProtoMessage()
func (*GetConnectionRequest) ProtoReflect ¶
func (x *GetConnectionRequest) ProtoReflect() protoreflect.Message
func (*GetConnectionRequest) Reset ¶
func (x *GetConnectionRequest) Reset()
func (*GetConnectionRequest) String ¶
func (x *GetConnectionRequest) String() string
type ListConnectionsRequest ¶
type ListConnectionsRequest struct {
// Required. Parent resource name.
// Must be in the form: `projects/{project_id}/locations/{location_id}`
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// Required. Maximum number of results per page.
MaxResults *wrapperspb.UInt32Value `protobuf:"bytes,2,opt,name=max_results,json=maxResults,proto3" json:"max_results,omitempty"`
// Page token.
PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
// contains filtered or unexported fields
}
The request for [ConnectionService.ListConnections][google.cloud.bigquery.connection.v1beta1.ConnectionService.ListConnections].
func (*ListConnectionsRequest) Descriptor
deprecated
func (*ListConnectionsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListConnectionsRequest.ProtoReflect.Descriptor instead.
func (*ListConnectionsRequest) GetMaxResults ¶
func (x *ListConnectionsRequest) GetMaxResults() *wrapperspb.UInt32Value
func (*ListConnectionsRequest) GetPageToken ¶
func (x *ListConnectionsRequest) GetPageToken() string
func (*ListConnectionsRequest) GetParent ¶
func (x *ListConnectionsRequest) GetParent() string
func (*ListConnectionsRequest) ProtoMessage ¶
func (*ListConnectionsRequest) ProtoMessage()
func (*ListConnectionsRequest) ProtoReflect ¶
func (x *ListConnectionsRequest) ProtoReflect() protoreflect.Message
func (*ListConnectionsRequest) Reset ¶
func (x *ListConnectionsRequest) Reset()
func (*ListConnectionsRequest) String ¶
func (x *ListConnectionsRequest) String() string
type ListConnectionsResponse ¶
type ListConnectionsResponse struct {
// Next page token.
NextPageToken string `protobuf:"bytes,1,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
// List of connections.
Connections []*Connection `protobuf:"bytes,2,rep,name=connections,proto3" json:"connections,omitempty"`
// contains filtered or unexported fields
}
The response for [ConnectionService.ListConnections][google.cloud.bigquery.connection.v1beta1.ConnectionService.ListConnections].
func (*ListConnectionsResponse) Descriptor
deprecated
func (*ListConnectionsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListConnectionsResponse.ProtoReflect.Descriptor instead.
func (*ListConnectionsResponse) GetConnections ¶
func (x *ListConnectionsResponse) GetConnections() []*Connection
func (*ListConnectionsResponse) GetNextPageToken ¶
func (x *ListConnectionsResponse) GetNextPageToken() string
func (*ListConnectionsResponse) ProtoMessage ¶
func (*ListConnectionsResponse) ProtoMessage()
func (*ListConnectionsResponse) ProtoReflect ¶
func (x *ListConnectionsResponse) ProtoReflect() protoreflect.Message
func (*ListConnectionsResponse) Reset ¶
func (x *ListConnectionsResponse) Reset()
func (*ListConnectionsResponse) String ¶
func (x *ListConnectionsResponse) String() string
type UnimplementedConnectionServiceServer ¶
type UnimplementedConnectionServiceServer struct {
}
UnimplementedConnectionServiceServer should be embedded to have forward compatible implementations.
func (UnimplementedConnectionServiceServer) CreateConnection ¶
func (UnimplementedConnectionServiceServer) CreateConnection(context.Context, *CreateConnectionRequest) (*Connection, error)
func (UnimplementedConnectionServiceServer) DeleteConnection ¶
func (UnimplementedConnectionServiceServer) DeleteConnection(context.Context, *DeleteConnectionRequest) (*emptypb.Empty, error)
func (UnimplementedConnectionServiceServer) GetConnection ¶
func (UnimplementedConnectionServiceServer) GetConnection(context.Context, *GetConnectionRequest) (*Connection, error)
func (UnimplementedConnectionServiceServer) GetIamPolicy ¶
func (UnimplementedConnectionServiceServer) GetIamPolicy(context.Context, *iampb.GetIamPolicyRequest) (*iampb.Policy, error)
func (UnimplementedConnectionServiceServer) ListConnections ¶
func (UnimplementedConnectionServiceServer) ListConnections(context.Context, *ListConnectionsRequest) (*ListConnectionsResponse, error)
func (UnimplementedConnectionServiceServer) SetIamPolicy ¶
func (UnimplementedConnectionServiceServer) SetIamPolicy(context.Context, *iampb.SetIamPolicyRequest) (*iampb.Policy, error)
func (UnimplementedConnectionServiceServer) TestIamPermissions ¶
func (UnimplementedConnectionServiceServer) TestIamPermissions(context.Context, *iampb.TestIamPermissionsRequest) (*iampb.TestIamPermissionsResponse, error)
func (UnimplementedConnectionServiceServer) UpdateConnection ¶
func (UnimplementedConnectionServiceServer) UpdateConnection(context.Context, *UpdateConnectionRequest) (*Connection, error)
func (UnimplementedConnectionServiceServer) UpdateConnectionCredential ¶
func (UnimplementedConnectionServiceServer) UpdateConnectionCredential(context.Context, *UpdateConnectionCredentialRequest) (*emptypb.Empty, error)
type UnsafeConnectionServiceServer ¶ added in v1.72.0
type UnsafeConnectionServiceServer interface {
// contains filtered or unexported methods
}
UnsafeConnectionServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ConnectionServiceServer will result in compilation errors.
type UpdateConnectionCredentialRequest ¶
type UpdateConnectionCredentialRequest struct {
// Required. Name of the connection, for example:
// `projects/{project_id}/locations/{location_id}/connections/{connection_id}/credential`
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Required. Credential to use with the connection.
Credential *ConnectionCredential `protobuf:"bytes,2,opt,name=credential,proto3" json:"credential,omitempty"`
// contains filtered or unexported fields
}
The request for [ConnectionService.UpdateConnectionCredential][google.cloud.bigquery.connection.v1beta1.ConnectionService.UpdateConnectionCredential].
func (*UpdateConnectionCredentialRequest) Descriptor
deprecated
func (*UpdateConnectionCredentialRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateConnectionCredentialRequest.ProtoReflect.Descriptor instead.
func (*UpdateConnectionCredentialRequest) GetCredential ¶
func (x *UpdateConnectionCredentialRequest) GetCredential() *ConnectionCredential
func (*UpdateConnectionCredentialRequest) GetName ¶
func (x *UpdateConnectionCredentialRequest) GetName() string
func (*UpdateConnectionCredentialRequest) ProtoMessage ¶
func (*UpdateConnectionCredentialRequest) ProtoMessage()
func (*UpdateConnectionCredentialRequest) ProtoReflect ¶
func (x *UpdateConnectionCredentialRequest) ProtoReflect() protoreflect.Message
func (*UpdateConnectionCredentialRequest) Reset ¶
func (x *UpdateConnectionCredentialRequest) Reset()
func (*UpdateConnectionCredentialRequest) String ¶
func (x *UpdateConnectionCredentialRequest) String() string
type UpdateConnectionRequest ¶
type UpdateConnectionRequest struct {
// Required. Name of the connection to update, for example:
// `projects/{project_id}/locations/{location_id}/connections/{connection_id}`
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Required. Connection containing the updated fields.
Connection *Connection `protobuf:"bytes,2,opt,name=connection,proto3" json:"connection,omitempty"`
// Required. Update mask for the connection fields to be updated.
UpdateMask *fieldmaskpb.FieldMask `protobuf:"bytes,3,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
// contains filtered or unexported fields
}
The request for [ConnectionService.UpdateConnection][google.cloud.bigquery.connection.v1beta1.ConnectionService.UpdateConnection].
func (*UpdateConnectionRequest) Descriptor
deprecated
func (*UpdateConnectionRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateConnectionRequest.ProtoReflect.Descriptor instead.
func (*UpdateConnectionRequest) GetConnection ¶
func (x *UpdateConnectionRequest) GetConnection() *Connection
func (*UpdateConnectionRequest) GetName ¶
func (x *UpdateConnectionRequest) GetName() string
func (*UpdateConnectionRequest) GetUpdateMask ¶
func (x *UpdateConnectionRequest) GetUpdateMask() *fieldmaskpb.FieldMask
func (*UpdateConnectionRequest) ProtoMessage ¶
func (*UpdateConnectionRequest) ProtoMessage()
func (*UpdateConnectionRequest) ProtoReflect ¶
func (x *UpdateConnectionRequest) ProtoReflect() protoreflect.Message
func (*UpdateConnectionRequest) Reset ¶
func (x *UpdateConnectionRequest) Reset()
func (*UpdateConnectionRequest) String ¶
func (x *UpdateConnectionRequest) String() string