Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterDataPolicyServiceServer(s grpc.ServiceRegistrar, srv DataPolicyServiceServer)
- type CreateDataPolicyRequest
- func (*CreateDataPolicyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateDataPolicyRequest) GetDataPolicy() *DataPolicy
- func (x *CreateDataPolicyRequest) GetParent() string
- func (*CreateDataPolicyRequest) ProtoMessage()
- func (x *CreateDataPolicyRequest) ProtoReflect() protoreflect.Message
- func (x *CreateDataPolicyRequest) Reset()
- func (x *CreateDataPolicyRequest) String() string
- type DataMaskingPolicy
- func (*DataMaskingPolicy) Descriptor() ([]byte, []int)deprecated
- func (x *DataMaskingPolicy) GetMaskingExpression() isDataMaskingPolicy_MaskingExpression
- func (x *DataMaskingPolicy) GetPredefinedExpression() DataMaskingPolicy_PredefinedExpression
- func (*DataMaskingPolicy) ProtoMessage()
- func (x *DataMaskingPolicy) ProtoReflect() protoreflect.Message
- func (x *DataMaskingPolicy) Reset()
- func (x *DataMaskingPolicy) String() string
- type DataMaskingPolicy_PredefinedExpression
- func (DataMaskingPolicy_PredefinedExpression) Descriptor() protoreflect.EnumDescriptor
- func (x DataMaskingPolicy_PredefinedExpression) Enum() *DataMaskingPolicy_PredefinedExpression
- func (DataMaskingPolicy_PredefinedExpression) EnumDescriptor() ([]byte, []int)deprecated
- func (x DataMaskingPolicy_PredefinedExpression) Number() protoreflect.EnumNumber
- func (x DataMaskingPolicy_PredefinedExpression) String() string
- func (DataMaskingPolicy_PredefinedExpression) Type() protoreflect.EnumType
- type DataMaskingPolicy_PredefinedExpression_
- type DataPolicy
- func (*DataPolicy) Descriptor() ([]byte, []int)deprecated
- func (x *DataPolicy) GetDataMaskingPolicy() *DataMaskingPolicy
- func (x *DataPolicy) GetDataPolicyId() string
- func (x *DataPolicy) GetDataPolicyType() DataPolicy_DataPolicyType
- func (x *DataPolicy) GetMatchingLabel() isDataPolicy_MatchingLabel
- func (x *DataPolicy) GetName() string
- func (x *DataPolicy) GetPolicy() isDataPolicy_Policy
- func (x *DataPolicy) GetPolicyTag() string
- func (*DataPolicy) ProtoMessage()
- func (x *DataPolicy) ProtoReflect() protoreflect.Message
- func (x *DataPolicy) Reset()
- func (x *DataPolicy) String() string
- type DataPolicyServiceClient
- type DataPolicyServiceServer
- type DataPolicy_DataMaskingPolicy
- type DataPolicy_DataPolicyType
- func (DataPolicy_DataPolicyType) Descriptor() protoreflect.EnumDescriptor
- func (x DataPolicy_DataPolicyType) Enum() *DataPolicy_DataPolicyType
- func (DataPolicy_DataPolicyType) EnumDescriptor() ([]byte, []int)deprecated
- func (x DataPolicy_DataPolicyType) Number() protoreflect.EnumNumber
- func (x DataPolicy_DataPolicyType) String() string
- func (DataPolicy_DataPolicyType) Type() protoreflect.EnumType
- type DataPolicy_PolicyTag
- type DeleteDataPolicyRequest
- func (*DeleteDataPolicyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteDataPolicyRequest) GetName() string
- func (*DeleteDataPolicyRequest) ProtoMessage()
- func (x *DeleteDataPolicyRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteDataPolicyRequest) Reset()
- func (x *DeleteDataPolicyRequest) String() string
- type GetDataPolicyRequest
- func (*GetDataPolicyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetDataPolicyRequest) GetName() string
- func (*GetDataPolicyRequest) ProtoMessage()
- func (x *GetDataPolicyRequest) ProtoReflect() protoreflect.Message
- func (x *GetDataPolicyRequest) Reset()
- func (x *GetDataPolicyRequest) String() string
- type ListDataPoliciesRequest
- func (*ListDataPoliciesRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ListDataPoliciesRequest) GetPageSize() int32
- func (x *ListDataPoliciesRequest) GetPageToken() string
- func (x *ListDataPoliciesRequest) GetParent() string
- func (*ListDataPoliciesRequest) ProtoMessage()
- func (x *ListDataPoliciesRequest) ProtoReflect() protoreflect.Message
- func (x *ListDataPoliciesRequest) Reset()
- func (x *ListDataPoliciesRequest) String() string
- type ListDataPoliciesResponse
- func (*ListDataPoliciesResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListDataPoliciesResponse) GetDataPolicies() []*DataPolicy
- func (x *ListDataPoliciesResponse) GetNextPageToken() string
- func (*ListDataPoliciesResponse) ProtoMessage()
- func (x *ListDataPoliciesResponse) ProtoReflect() protoreflect.Message
- func (x *ListDataPoliciesResponse) Reset()
- func (x *ListDataPoliciesResponse) String() string
- type UnimplementedDataPolicyServiceServer
- func (UnimplementedDataPolicyServiceServer) CreateDataPolicy(context.Context, *CreateDataPolicyRequest) (*DataPolicy, error)
- func (UnimplementedDataPolicyServiceServer) DeleteDataPolicy(context.Context, *DeleteDataPolicyRequest) (*emptypb.Empty, error)
- func (UnimplementedDataPolicyServiceServer) GetDataPolicy(context.Context, *GetDataPolicyRequest) (*DataPolicy, error)
- func (UnimplementedDataPolicyServiceServer) GetIamPolicy(context.Context, *iampb.GetIamPolicyRequest) (*iampb.Policy, error)
- func (UnimplementedDataPolicyServiceServer) ListDataPolicies(context.Context, *ListDataPoliciesRequest) (*ListDataPoliciesResponse, error)
- func (UnimplementedDataPolicyServiceServer) SetIamPolicy(context.Context, *iampb.SetIamPolicyRequest) (*iampb.Policy, error)
- func (UnimplementedDataPolicyServiceServer) TestIamPermissions(context.Context, *iampb.TestIamPermissionsRequest) (*iampb.TestIamPermissionsResponse, error)
- func (UnimplementedDataPolicyServiceServer) UpdateDataPolicy(context.Context, *UpdateDataPolicyRequest) (*DataPolicy, error)
- type UnsafeDataPolicyServiceServer
- type UpdateDataPolicyRequest
- func (*UpdateDataPolicyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateDataPolicyRequest) GetDataPolicy() *DataPolicy
- func (x *UpdateDataPolicyRequest) GetUpdateMask() *fieldmaskpb.FieldMask
- func (*UpdateDataPolicyRequest) ProtoMessage()
- func (x *UpdateDataPolicyRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateDataPolicyRequest) Reset()
- func (x *UpdateDataPolicyRequest) String() string
Constants ¶
const ( DataPolicyService_CreateDataPolicy_FullMethodName = "/google.cloud.bigquery.datapolicies.v1beta1.DataPolicyService/CreateDataPolicy" DataPolicyService_UpdateDataPolicy_FullMethodName = "/google.cloud.bigquery.datapolicies.v1beta1.DataPolicyService/UpdateDataPolicy" DataPolicyService_DeleteDataPolicy_FullMethodName = "/google.cloud.bigquery.datapolicies.v1beta1.DataPolicyService/DeleteDataPolicy" DataPolicyService_GetDataPolicy_FullMethodName = "/google.cloud.bigquery.datapolicies.v1beta1.DataPolicyService/GetDataPolicy" DataPolicyService_ListDataPolicies_FullMethodName = "/google.cloud.bigquery.datapolicies.v1beta1.DataPolicyService/ListDataPolicies" DataPolicyService_GetIamPolicy_FullMethodName = "/google.cloud.bigquery.datapolicies.v1beta1.DataPolicyService/GetIamPolicy" DataPolicyService_SetIamPolicy_FullMethodName = "/google.cloud.bigquery.datapolicies.v1beta1.DataPolicyService/SetIamPolicy" DataPolicyService_TestIamPermissions_FullMethodName = "/google.cloud.bigquery.datapolicies.v1beta1.DataPolicyService/TestIamPermissions" )
Variables ¶
var ( DataPolicy_DataPolicyType_name = map[int32]string{ 0: "DATA_POLICY_TYPE_UNSPECIFIED", 3: "COLUMN_LEVEL_SECURITY_POLICY", 2: "DATA_MASKING_POLICY", } DataPolicy_DataPolicyType_value = map[string]int32{ "DATA_POLICY_TYPE_UNSPECIFIED": 0, "COLUMN_LEVEL_SECURITY_POLICY": 3, "DATA_MASKING_POLICY": 2, } )
Enum value maps for DataPolicy_DataPolicyType.
var ( DataMaskingPolicy_PredefinedExpression_name = map[int32]string{ 0: "PREDEFINED_EXPRESSION_UNSPECIFIED", 3: "SHA256", 5: "ALWAYS_NULL", 7: "DEFAULT_MASKING_VALUE", } DataMaskingPolicy_PredefinedExpression_value = map[string]int32{ "PREDEFINED_EXPRESSION_UNSPECIFIED": 0, "SHA256": 3, "ALWAYS_NULL": 5, "DEFAULT_MASKING_VALUE": 7, } )
Enum value maps for DataMaskingPolicy_PredefinedExpression.
var DataPolicyService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "google.cloud.bigquery.datapolicies.v1beta1.DataPolicyService", HandlerType: (*DataPolicyServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateDataPolicy", Handler: _DataPolicyService_CreateDataPolicy_Handler, }, { MethodName: "UpdateDataPolicy", Handler: _DataPolicyService_UpdateDataPolicy_Handler, }, { MethodName: "DeleteDataPolicy", Handler: _DataPolicyService_DeleteDataPolicy_Handler, }, { MethodName: "GetDataPolicy", Handler: _DataPolicyService_GetDataPolicy_Handler, }, { MethodName: "ListDataPolicies", Handler: _DataPolicyService_ListDataPolicies_Handler, }, { MethodName: "GetIamPolicy", Handler: _DataPolicyService_GetIamPolicy_Handler, }, { MethodName: "SetIamPolicy", Handler: _DataPolicyService_SetIamPolicy_Handler, }, { MethodName: "TestIamPermissions", Handler: _DataPolicyService_TestIamPermissions_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "google/cloud/bigquery/datapolicies/v1beta1/datapolicy.proto", }
DataPolicyService_ServiceDesc is the grpc.ServiceDesc for DataPolicyService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_google_cloud_bigquery_datapolicies_v1beta1_datapolicy_proto protoreflect.FileDescriptor
Functions ¶
func RegisterDataPolicyServiceServer ¶
func RegisterDataPolicyServiceServer(s grpc.ServiceRegistrar, srv DataPolicyServiceServer)
Types ¶
type CreateDataPolicyRequest ¶
type CreateDataPolicyRequest struct {
// Required. Resource name of the project that the data policy will belong to. The
// format is `projects/{project_number}/locations/{location_id}`.
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// Required. The data policy to create. The `name` field does not need to be
// provided for the data policy creation.
DataPolicy *DataPolicy `protobuf:"bytes,2,opt,name=data_policy,json=dataPolicy,proto3" json:"data_policy,omitempty"`
// contains filtered or unexported fields
}
Request message for the CreateDataPolicy method.
func (*CreateDataPolicyRequest) Descriptor
deprecated
func (*CreateDataPolicyRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateDataPolicyRequest.ProtoReflect.Descriptor instead.
func (*CreateDataPolicyRequest) GetDataPolicy ¶
func (x *CreateDataPolicyRequest) GetDataPolicy() *DataPolicy
func (*CreateDataPolicyRequest) GetParent ¶
func (x *CreateDataPolicyRequest) GetParent() string
func (*CreateDataPolicyRequest) ProtoMessage ¶
func (*CreateDataPolicyRequest) ProtoMessage()
func (*CreateDataPolicyRequest) ProtoReflect ¶
func (x *CreateDataPolicyRequest) ProtoReflect() protoreflect.Message
func (*CreateDataPolicyRequest) Reset ¶
func (x *CreateDataPolicyRequest) Reset()
func (*CreateDataPolicyRequest) String ¶
func (x *CreateDataPolicyRequest) String() string
type DataMaskingPolicy ¶
type DataMaskingPolicy struct {
// A masking expression to bind to the data masking rule.
//
// Types that are valid to be assigned to MaskingExpression:
//
// *DataMaskingPolicy_PredefinedExpression_
MaskingExpression isDataMaskingPolicy_MaskingExpression `protobuf_oneof:"masking_expression"`
// contains filtered or unexported fields
}
The data masking policy that is used to specify data masking rule.
func (*DataMaskingPolicy) Descriptor
deprecated
func (*DataMaskingPolicy) Descriptor() ([]byte, []int)
Deprecated: Use DataMaskingPolicy.ProtoReflect.Descriptor instead.
func (*DataMaskingPolicy) GetMaskingExpression ¶
func (x *DataMaskingPolicy) GetMaskingExpression() isDataMaskingPolicy_MaskingExpression
func (*DataMaskingPolicy) GetPredefinedExpression ¶
func (x *DataMaskingPolicy) GetPredefinedExpression() DataMaskingPolicy_PredefinedExpression
func (*DataMaskingPolicy) ProtoMessage ¶
func (*DataMaskingPolicy) ProtoMessage()
func (*DataMaskingPolicy) ProtoReflect ¶
func (x *DataMaskingPolicy) ProtoReflect() protoreflect.Message
func (*DataMaskingPolicy) Reset ¶
func (x *DataMaskingPolicy) Reset()
func (*DataMaskingPolicy) String ¶
func (x *DataMaskingPolicy) String() string
type DataMaskingPolicy_PredefinedExpression ¶
type DataMaskingPolicy_PredefinedExpression int32
The available masking rules. Learn more here: https://cloud.google.com/bigquery/docs/column-data-masking-intro#masking_options.
const ( // Default, unspecified predefined expression. No masking will take place // since no expression is specified. DataMaskingPolicy_PREDEFINED_EXPRESSION_UNSPECIFIED DataMaskingPolicy_PredefinedExpression = 0 // Masking expression to replace data with SHA-256 hash. DataMaskingPolicy_SHA256 DataMaskingPolicy_PredefinedExpression = 3 // Masking expression to replace data with NULLs. DataMaskingPolicy_ALWAYS_NULL DataMaskingPolicy_PredefinedExpression = 5 // Masking expression to replace data with their default masking values. // The default masking values for each type listed as below: // // * STRING: "" // * BYTES: b” // * INTEGER: 0 // * FLOAT: 0.0 // * NUMERIC: 0 // * BOOLEAN: FALSE // * TIMESTAMP: 0001-01-01 00:00:00 UTC // * DATE: 0001-01-01 // * TIME: 00:00:00 // * DATETIME: 0001-01-01T00:00:00 // * GEOGRAPHY: POINT(0 0) // * BIGNUMERIC: 0 // * ARRAY: [] // * STRUCT: NOT_APPLICABLE // * JSON: NULL DataMaskingPolicy_DEFAULT_MASKING_VALUE DataMaskingPolicy_PredefinedExpression = 7 )
func (DataMaskingPolicy_PredefinedExpression) Descriptor ¶
func (DataMaskingPolicy_PredefinedExpression) Descriptor() protoreflect.EnumDescriptor
func (DataMaskingPolicy_PredefinedExpression) EnumDescriptor
deprecated
func (DataMaskingPolicy_PredefinedExpression) EnumDescriptor() ([]byte, []int)
Deprecated: Use DataMaskingPolicy_PredefinedExpression.Descriptor instead.
func (DataMaskingPolicy_PredefinedExpression) Number ¶
func (x DataMaskingPolicy_PredefinedExpression) Number() protoreflect.EnumNumber
func (DataMaskingPolicy_PredefinedExpression) String ¶
func (x DataMaskingPolicy_PredefinedExpression) String() string
func (DataMaskingPolicy_PredefinedExpression) Type ¶
func (DataMaskingPolicy_PredefinedExpression) Type() protoreflect.EnumType
type DataMaskingPolicy_PredefinedExpression_ ¶
type DataMaskingPolicy_PredefinedExpression_ struct {
// A predefined masking expression.
PredefinedExpression DataMaskingPolicy_PredefinedExpression `` /* 176-byte string literal not displayed */
}
type DataPolicy ¶
type DataPolicy struct {
// Label that is bound to this data policy.
//
// Types that are valid to be assigned to MatchingLabel:
//
// *DataPolicy_PolicyTag
MatchingLabel isDataPolicy_MatchingLabel `protobuf_oneof:"matching_label"`
// The policy that is bound to this data policy.
//
// Types that are valid to be assigned to Policy:
//
// *DataPolicy_DataMaskingPolicy
Policy isDataPolicy_Policy `protobuf_oneof:"policy"`
// Output only. Resource name of this data policy, in the format of
// `projects/{project_number}/locations/{location_id}/dataPolicies/{data_policy_id}`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Type of data policy.
DataPolicyType DataPolicy_DataPolicyType `` /* 180-byte string literal not displayed */
// User-assigned (human readable) ID of the data policy that needs to be
// unique within a project. Used as {data_policy_id} in part of the resource
// name.
DataPolicyId string `protobuf:"bytes,3,opt,name=data_policy_id,json=dataPolicyId,proto3" json:"data_policy_id,omitempty"`
// contains filtered or unexported fields
}
Represents the label-policy binding.
func (*DataPolicy) Descriptor
deprecated
func (*DataPolicy) Descriptor() ([]byte, []int)
Deprecated: Use DataPolicy.ProtoReflect.Descriptor instead.
func (*DataPolicy) GetDataMaskingPolicy ¶
func (x *DataPolicy) GetDataMaskingPolicy() *DataMaskingPolicy
func (*DataPolicy) GetDataPolicyId ¶
func (x *DataPolicy) GetDataPolicyId() string
func (*DataPolicy) GetDataPolicyType ¶
func (x *DataPolicy) GetDataPolicyType() DataPolicy_DataPolicyType
func (*DataPolicy) GetMatchingLabel ¶
func (x *DataPolicy) GetMatchingLabel() isDataPolicy_MatchingLabel
func (*DataPolicy) GetName ¶
func (x *DataPolicy) GetName() string
func (*DataPolicy) GetPolicy ¶
func (x *DataPolicy) GetPolicy() isDataPolicy_Policy
func (*DataPolicy) GetPolicyTag ¶
func (x *DataPolicy) GetPolicyTag() string
func (*DataPolicy) ProtoMessage ¶
func (*DataPolicy) ProtoMessage()
func (*DataPolicy) ProtoReflect ¶
func (x *DataPolicy) ProtoReflect() protoreflect.Message
func (*DataPolicy) Reset ¶
func (x *DataPolicy) Reset()
func (*DataPolicy) String ¶
func (x *DataPolicy) String() string
type DataPolicyServiceClient ¶
type DataPolicyServiceClient interface {
// Creates a new data policy under a project with the given `dataPolicyId`
// (used as the display name), policy tag, and data policy type.
CreateDataPolicy(ctx context.Context, in *CreateDataPolicyRequest, opts ...grpc.CallOption) (*DataPolicy, error)
// Updates the metadata for an existing data policy. The target data policy
// can be specified by the resource name.
UpdateDataPolicy(ctx context.Context, in *UpdateDataPolicyRequest, opts ...grpc.CallOption) (*DataPolicy, error)
// Deletes the data policy specified by its resource name.
DeleteDataPolicy(ctx context.Context, in *DeleteDataPolicyRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
// Gets the data policy specified by its resource name.
GetDataPolicy(ctx context.Context, in *GetDataPolicyRequest, opts ...grpc.CallOption) (*DataPolicy, error)
// List all of the data policies in the specified parent project.
ListDataPolicies(ctx context.Context, in *ListDataPoliciesRequest, opts ...grpc.CallOption) (*ListDataPoliciesResponse, error)
// Gets the IAM policy for the specified data policy.
GetIamPolicy(ctx context.Context, in *iampb.GetIamPolicyRequest, opts ...grpc.CallOption) (*iampb.Policy, error)
// Sets the IAM policy for the specified data policy.
SetIamPolicy(ctx context.Context, in *iampb.SetIamPolicyRequest, opts ...grpc.CallOption) (*iampb.Policy, error)
// Returns the caller's permission on the specified data policy resource.
TestIamPermissions(ctx context.Context, in *iampb.TestIamPermissionsRequest, opts ...grpc.CallOption) (*iampb.TestIamPermissionsResponse, error)
}
DataPolicyServiceClient is the client API for DataPolicyService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewDataPolicyServiceClient ¶
func NewDataPolicyServiceClient(cc grpc.ClientConnInterface) DataPolicyServiceClient
type DataPolicyServiceServer ¶
type DataPolicyServiceServer interface {
// Creates a new data policy under a project with the given `dataPolicyId`
// (used as the display name), policy tag, and data policy type.
CreateDataPolicy(context.Context, *CreateDataPolicyRequest) (*DataPolicy, error)
// Updates the metadata for an existing data policy. The target data policy
// can be specified by the resource name.
UpdateDataPolicy(context.Context, *UpdateDataPolicyRequest) (*DataPolicy, error)
// Deletes the data policy specified by its resource name.
DeleteDataPolicy(context.Context, *DeleteDataPolicyRequest) (*emptypb.Empty, error)
// Gets the data policy specified by its resource name.
GetDataPolicy(context.Context, *GetDataPolicyRequest) (*DataPolicy, error)
// List all of the data policies in the specified parent project.
ListDataPolicies(context.Context, *ListDataPoliciesRequest) (*ListDataPoliciesResponse, error)
// Gets the IAM policy for the specified data policy.
GetIamPolicy(context.Context, *iampb.GetIamPolicyRequest) (*iampb.Policy, error)
// Sets the IAM policy for the specified data policy.
SetIamPolicy(context.Context, *iampb.SetIamPolicyRequest) (*iampb.Policy, error)
// Returns the caller's permission on the specified data policy resource.
TestIamPermissions(context.Context, *iampb.TestIamPermissionsRequest) (*iampb.TestIamPermissionsResponse, error)
}
DataPolicyServiceServer is the server API for DataPolicyService service. All implementations should embed UnimplementedDataPolicyServiceServer for forward compatibility
type DataPolicy_DataMaskingPolicy ¶
type DataPolicy_DataMaskingPolicy struct {
// The data masking policy that specifies the data masking rule to use.
DataMaskingPolicy *DataMaskingPolicy `protobuf:"bytes,5,opt,name=data_masking_policy,json=dataMaskingPolicy,proto3,oneof"`
}
type DataPolicy_DataPolicyType ¶
type DataPolicy_DataPolicyType int32
A list of supported data policy types.
const ( // Default value for the data policy type. This should not be used. DataPolicy_DATA_POLICY_TYPE_UNSPECIFIED DataPolicy_DataPolicyType = 0 // Used to create a data policy for column-level security, without data // masking. DataPolicy_COLUMN_LEVEL_SECURITY_POLICY DataPolicy_DataPolicyType = 3 // Used to create a data policy for data masking. DataPolicy_DATA_MASKING_POLICY DataPolicy_DataPolicyType = 2 )
func (DataPolicy_DataPolicyType) Descriptor ¶
func (DataPolicy_DataPolicyType) Descriptor() protoreflect.EnumDescriptor
func (DataPolicy_DataPolicyType) Enum ¶
func (x DataPolicy_DataPolicyType) Enum() *DataPolicy_DataPolicyType
func (DataPolicy_DataPolicyType) EnumDescriptor
deprecated
func (DataPolicy_DataPolicyType) EnumDescriptor() ([]byte, []int)
Deprecated: Use DataPolicy_DataPolicyType.Descriptor instead.
func (DataPolicy_DataPolicyType) Number ¶
func (x DataPolicy_DataPolicyType) Number() protoreflect.EnumNumber
func (DataPolicy_DataPolicyType) String ¶
func (x DataPolicy_DataPolicyType) String() string
func (DataPolicy_DataPolicyType) Type ¶
func (DataPolicy_DataPolicyType) Type() protoreflect.EnumType
type DataPolicy_PolicyTag ¶
type DataPolicy_PolicyTag struct {
// Policy tag resource name, in the format of
// `projects/{project_number}/locations/{location_id}/taxonomies/{taxonomy_id}/policyTags/{policyTag_id}`.
PolicyTag string `protobuf:"bytes,4,opt,name=policy_tag,json=policyTag,proto3,oneof"`
}
type DeleteDataPolicyRequest ¶
type DeleteDataPolicyRequest struct {
// Required. Resource name of the data policy to delete. Format is
// `projects/{project_number}/locations/{location_id}/dataPolicies/{data_policy_id}`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
Request message for the DeleteDataPolicy method.
func (*DeleteDataPolicyRequest) Descriptor
deprecated
func (*DeleteDataPolicyRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteDataPolicyRequest.ProtoReflect.Descriptor instead.
func (*DeleteDataPolicyRequest) GetName ¶
func (x *DeleteDataPolicyRequest) GetName() string
func (*DeleteDataPolicyRequest) ProtoMessage ¶
func (*DeleteDataPolicyRequest) ProtoMessage()
func (*DeleteDataPolicyRequest) ProtoReflect ¶
func (x *DeleteDataPolicyRequest) ProtoReflect() protoreflect.Message
func (*DeleteDataPolicyRequest) Reset ¶
func (x *DeleteDataPolicyRequest) Reset()
func (*DeleteDataPolicyRequest) String ¶
func (x *DeleteDataPolicyRequest) String() string
type GetDataPolicyRequest ¶
type GetDataPolicyRequest struct {
// Required. Resource name of the requested data policy. Format is
// `projects/{project_number}/locations/{location_id}/dataPolicies/{data_policy_id}`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
Request message for the GetDataPolicy method.
func (*GetDataPolicyRequest) Descriptor
deprecated
func (*GetDataPolicyRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetDataPolicyRequest.ProtoReflect.Descriptor instead.
func (*GetDataPolicyRequest) GetName ¶
func (x *GetDataPolicyRequest) GetName() string
func (*GetDataPolicyRequest) ProtoMessage ¶
func (*GetDataPolicyRequest) ProtoMessage()
func (*GetDataPolicyRequest) ProtoReflect ¶
func (x *GetDataPolicyRequest) ProtoReflect() protoreflect.Message
func (*GetDataPolicyRequest) Reset ¶
func (x *GetDataPolicyRequest) Reset()
func (*GetDataPolicyRequest) String ¶
func (x *GetDataPolicyRequest) String() string
type ListDataPoliciesRequest ¶
type ListDataPoliciesRequest struct {
// Required. Resource name of the project for which to list data policies. Format is
// `projects/{project_number}/locations/{location_id}`.
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// The maximum number of data policies to return. Must be a value between 1
// and 1000.
// If not set, defaults to 50.
PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
// The `nextPageToken` value returned from a previous list request, if any. If
// not set, defaults to an empty string.
PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
// contains filtered or unexported fields
}
Request message for the ListDataPolicies method.
func (*ListDataPoliciesRequest) Descriptor
deprecated
func (*ListDataPoliciesRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListDataPoliciesRequest.ProtoReflect.Descriptor instead.
func (*ListDataPoliciesRequest) GetPageSize ¶
func (x *ListDataPoliciesRequest) GetPageSize() int32
func (*ListDataPoliciesRequest) GetPageToken ¶
func (x *ListDataPoliciesRequest) GetPageToken() string
func (*ListDataPoliciesRequest) GetParent ¶
func (x *ListDataPoliciesRequest) GetParent() string
func (*ListDataPoliciesRequest) ProtoMessage ¶
func (*ListDataPoliciesRequest) ProtoMessage()
func (*ListDataPoliciesRequest) ProtoReflect ¶
func (x *ListDataPoliciesRequest) ProtoReflect() protoreflect.Message
func (*ListDataPoliciesRequest) Reset ¶
func (x *ListDataPoliciesRequest) Reset()
func (*ListDataPoliciesRequest) String ¶
func (x *ListDataPoliciesRequest) String() string
type ListDataPoliciesResponse ¶
type ListDataPoliciesResponse struct {
// Data policies that belong to the requested project.
DataPolicies []*DataPolicy `protobuf:"bytes,1,rep,name=data_policies,json=dataPolicies,proto3" json:"data_policies,omitempty"`
// Token used to retrieve the next page of results, or empty if there are no
// more results.
NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
// contains filtered or unexported fields
}
Response message for the ListDataPolicies method.
func (*ListDataPoliciesResponse) Descriptor
deprecated
func (*ListDataPoliciesResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListDataPoliciesResponse.ProtoReflect.Descriptor instead.
func (*ListDataPoliciesResponse) GetDataPolicies ¶
func (x *ListDataPoliciesResponse) GetDataPolicies() []*DataPolicy
func (*ListDataPoliciesResponse) GetNextPageToken ¶
func (x *ListDataPoliciesResponse) GetNextPageToken() string
func (*ListDataPoliciesResponse) ProtoMessage ¶
func (*ListDataPoliciesResponse) ProtoMessage()
func (*ListDataPoliciesResponse) ProtoReflect ¶
func (x *ListDataPoliciesResponse) ProtoReflect() protoreflect.Message
func (*ListDataPoliciesResponse) Reset ¶
func (x *ListDataPoliciesResponse) Reset()
func (*ListDataPoliciesResponse) String ¶
func (x *ListDataPoliciesResponse) String() string
type UnimplementedDataPolicyServiceServer ¶
type UnimplementedDataPolicyServiceServer struct {
}
UnimplementedDataPolicyServiceServer should be embedded to have forward compatible implementations.
func (UnimplementedDataPolicyServiceServer) CreateDataPolicy ¶
func (UnimplementedDataPolicyServiceServer) CreateDataPolicy(context.Context, *CreateDataPolicyRequest) (*DataPolicy, error)
func (UnimplementedDataPolicyServiceServer) DeleteDataPolicy ¶
func (UnimplementedDataPolicyServiceServer) DeleteDataPolicy(context.Context, *DeleteDataPolicyRequest) (*emptypb.Empty, error)
func (UnimplementedDataPolicyServiceServer) GetDataPolicy ¶
func (UnimplementedDataPolicyServiceServer) GetDataPolicy(context.Context, *GetDataPolicyRequest) (*DataPolicy, error)
func (UnimplementedDataPolicyServiceServer) GetIamPolicy ¶
func (UnimplementedDataPolicyServiceServer) GetIamPolicy(context.Context, *iampb.GetIamPolicyRequest) (*iampb.Policy, error)
func (UnimplementedDataPolicyServiceServer) ListDataPolicies ¶
func (UnimplementedDataPolicyServiceServer) ListDataPolicies(context.Context, *ListDataPoliciesRequest) (*ListDataPoliciesResponse, error)
func (UnimplementedDataPolicyServiceServer) SetIamPolicy ¶
func (UnimplementedDataPolicyServiceServer) SetIamPolicy(context.Context, *iampb.SetIamPolicyRequest) (*iampb.Policy, error)
func (UnimplementedDataPolicyServiceServer) TestIamPermissions ¶
func (UnimplementedDataPolicyServiceServer) TestIamPermissions(context.Context, *iampb.TestIamPermissionsRequest) (*iampb.TestIamPermissionsResponse, error)
func (UnimplementedDataPolicyServiceServer) UpdateDataPolicy ¶
func (UnimplementedDataPolicyServiceServer) UpdateDataPolicy(context.Context, *UpdateDataPolicyRequest) (*DataPolicy, error)
type UnsafeDataPolicyServiceServer ¶ added in v1.72.0
type UnsafeDataPolicyServiceServer interface {
// contains filtered or unexported methods
}
UnsafeDataPolicyServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DataPolicyServiceServer will result in compilation errors.
type UpdateDataPolicyRequest ¶
type UpdateDataPolicyRequest struct {
// Required. Update the data policy's metadata.
//
// The target data policy is determined by the `name` field.
// Other fields are updated to the specified values based on the field masks.
DataPolicy *DataPolicy `protobuf:"bytes,1,opt,name=data_policy,json=dataPolicy,proto3" json:"data_policy,omitempty"`
// The update mask applies to the resource. For the `FieldMask` definition,
// see
// https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
// If not set, defaults to all of the fields that are allowed to update.
//
// Updates to the `name` and `dataPolicyId` fields are not allowed.
UpdateMask *fieldmaskpb.FieldMask `protobuf:"bytes,2,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
// contains filtered or unexported fields
}
Response message for the UpdateDataPolicy method.
func (*UpdateDataPolicyRequest) Descriptor
deprecated
func (*UpdateDataPolicyRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateDataPolicyRequest.ProtoReflect.Descriptor instead.
func (*UpdateDataPolicyRequest) GetDataPolicy ¶
func (x *UpdateDataPolicyRequest) GetDataPolicy() *DataPolicy
func (*UpdateDataPolicyRequest) GetUpdateMask ¶
func (x *UpdateDataPolicyRequest) GetUpdateMask() *fieldmaskpb.FieldMask
func (*UpdateDataPolicyRequest) ProtoMessage ¶
func (*UpdateDataPolicyRequest) ProtoMessage()
func (*UpdateDataPolicyRequest) ProtoReflect ¶
func (x *UpdateDataPolicyRequest) ProtoReflect() protoreflect.Message
func (*UpdateDataPolicyRequest) Reset ¶
func (x *UpdateDataPolicyRequest) Reset()
func (*UpdateDataPolicyRequest) String ¶
func (x *UpdateDataPolicyRequest) String() string